package com.ynet.life.sujrb.file.parser;

import com.ynet.gene.core.Context;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.BatchSkdInfoSummary;
import com.ynet.life.sujrb.file.FileConstants;
import java.io.FileInputStream;
import java.io.IOException;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.regex.Pattern;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFDateUtil;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.OfficeXmlFileException;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/BatchSkdInfo.class */
public class BatchSkdInfo implements BatchFileParserInterface {
    private String formatter;
    private Context context;

    public BatchSkdInfo() {
    }

    public BatchSkdInfo(String formatter) {
        this.formatter = formatter;
    }

    public Context getContext() {
        return this.context;
    }

    public void setContext(Context context) {
        this.context = context;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        try {
            POIFSFileSystem file = new POIFSFileSystem(new FileInputStream(filePathName));
            HSSFWorkbook workBook = new HSSFWorkbook(file);
            BatchSkdInfoSummary result = new BatchSkdInfoSummary();
            try {
                HSSFSheet sheet = workBook.getSheetAt(0);
                sheet.getRow(0);
                int rowIndex = 1;
                HSSFRow recordRowTemp = sheet.getRow(1);
                if (getCellContent(recordRowTemp, 0, true).trim().equals("结束")) {
                    throw new TranFailException("excelError", "文件解析失败");
                }
                while (true) {
                    int i = rowIndex;
                    rowIndex++;
                    HSSFRow recordRow = sheet.getRow(i);
                    if (!getCellContent(recordRow, 0, true).trim().equals("结束")) {
                        if (this.formatter == null) {
                            result.addRecord(getRecordMap(recordRow));
                        } else {
                            result.addRecord(getRecordMap(recordRow, this.formatter));
                        }
                    } else {
                        return result;
                    }
                }
            } catch (Exception ex) {
                Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
                throw FileConstants.EXCEPTION_PARSE_FAIL;
            }
        } catch (OfficeXmlFileException e) {
            Trace.logError("LifeFile", "Excel版本过高", e);
            throw new TranFailException("excelError", "Excel版本过高");
        } catch (IOException ex2) {
            Trace.logError("LifeFile", "文件读取失败", ex2);
            throw new TranFailException("excelError", "文件读取失败");
        }
    }

    private Map getRecordMap(HSSFRow recordRow) throws TranFailException {
        Map result = new HashMap();
        String didCorName = getCellContent(recordRow, 0, true);
        String didLoanProsess = getCellContent(recordRow, 1, true);
        String didType = getCellContent(recordRow, 2, true);
        String didFinanceName = getCellContent(recordRow, 3, true);
        String didApplyAmt = getCellContent(recordRow, 4, false);
        String didLocalAgreeAmt = getCellContent(recordRow, 5, false);
        String didProAgreeAmt = getCellContent(recordRow, 6, false);
        String didLocalRisk = getCellContent(recordRow, 7, false);
        String didLocFilingDate = getCellContent(recordRow, 8, false);
        String didActualLoanAmt = getCellContent(recordRow, 9, false);
        String didLoanDate = getCellContent(recordRow, 10, false);
        String didLoanRepayDate = getCellContent(recordRow, 11, false);
        String didLoanDeclaration = getCellContent(recordRow, 12, false);
        String remark = "";
        if ("".equals(didCorName) || didCorName == null) {
            remark = String.valueOf(remark) + "企业名称为空";
        }
        if ("".equals(didLoanProsess) || didLoanProsess == null) {
            remark = String.valueOf(remark) + " 贷款进程为空";
        }
        if ("".equals(didType) || didType == null) {
            remark = String.valueOf(remark) + " 苏科贷类型为空";
        }
        if ("".equals(didFinanceName) || didFinanceName == null) {
            remark = String.valueOf(remark) + " 贷款银行-总行为空";
        }
        if ("".equals(didApplyAmt) || didApplyAmt == null) {
            remark = String.valueOf(remark) + " 申请苏科贷金额为空";
        } else if (!Pattern.compile("^[1-9]{1}\\d*$").matcher(didApplyAmt).matches()) {
            remark = String.valueOf(remark) + " 申请苏科贷金额不符合规则";
        }
        if ("".equals(didLocalAgreeAmt) || didLocalAgreeAmt == null) {
            remark = String.valueOf(remark) + " 地方同意备案金额为空";
        } else if (!Pattern.compile("^[1-9]{1}\\d*$").matcher(didLocalAgreeAmt).matches()) {
            remark = String.valueOf(remark) + " 地方同意备案金额不符合规则";
        }
        if ("".equals(didProAgreeAmt) || didProAgreeAmt == null) {
            remark = String.valueOf(remark) + " 省同意备案金额为空";
        } else if (!Pattern.compile("^[1-9]{1}\\d*$").matcher(didProAgreeAmt).matches()) {
            remark = String.valueOf(remark) + " 省同意备案金额不符合规则";
        }
        if ("".equals(didLocalRisk) || didLocalRisk == null) {
            remark = String.valueOf(remark) + " 地方承担风险补偿比例为空";
        } else if (!Pattern.compile("^[1-9]{1}\\d*$").matcher(didLocalRisk).matches()) {
            remark = String.valueOf(remark) + " 地方承担风险补偿比例不符合规则";
        }
        if ("".equals(didLocFilingDate) || didLocFilingDate == null) {
            remark = String.valueOf(remark) + " 地方同意备案日期为空";
        } else if (!Pattern.compile("^((\\d{2}(([02468][048])|([13579][26]))[\\-]{1}((((0?[13578])|(1[02]))[\\-]{1}((0?[1-9])|([1-2][0-9])|(3[01])))|(((0?[469])|(11))[\\-]{1}((0?[1-9])|([1-2][0-9])|(30)))|(0?2[\\-]{1}((0?[1-9])|([1-2][0-9])))))|(\\d{2}(([02468][1235679])|([13579][01345789]))[\\-]{1}((((0?[13578])|(1[02]))[\\-]{1}((0?[1-9])|([1-2][0-9])|(3[01])))|(((0?[469])|(11))[\\-]{1}((0?[1-9])|([1-2][0-9])|(30)))|(0?2[\\-]{1}((0?[1-9])|(1[0-9])|(2[0-8]))))))?\\s{1}((((0?[0-9])|([1][0-9])|([2][0-4]))\\:([0-5]?[0-9])((\\s)|(\\:([0-5]?[0-9])))))?$").matcher(didLocFilingDate).matches()) {
            remark = String.valueOf(remark) + " 地方同意备案日期不符合规则";
        }
        if ("".equals(didActualLoanAmt) || didActualLoanAmt == null) {
            remark = String.valueOf(remark) + " 实际放款金额为空";
        } else if (!Pattern.compile("^[1-9]{1}\\d*$").matcher(didActualLoanAmt).matches()) {
            remark = String.valueOf(remark) + " 实际放款金额不符合规则";
        }
        if ("".equals(didLoanDate) || didLoanDate == null) {
            remark = String.valueOf(remark) + " 贷款发放日期为空";
        } else if (!Pattern.compile("^((\\d{2}(([02468][048])|([13579][26]))[\\-]{1}((((0?[13578])|(1[02]))[\\-]{1}((0?[1-9])|([1-2][0-9])|(3[01])))|(((0?[469])|(11))[\\-]{1}((0?[1-9])|([1-2][0-9])|(30)))|(0?2[\\-]{1}((0?[1-9])|([1-2][0-9])))))|(\\d{2}(([02468][1235679])|([13579][01345789]))[\\-]{1}((((0?[13578])|(1[02]))[\\-]{1}((0?[1-9])|([1-2][0-9])|(3[01])))|(((0?[469])|(11))[\\-]{1}((0?[1-9])|([1-2][0-9])|(30)))|(0?2[\\-]{1}((0?[1-9])|(1[0-9])|(2[0-8]))))))?\\s{1}((((0?[0-9])|([1][0-9])|([2][0-4]))\\:([0-5]?[0-9])((\\s)|(\\:([0-5]?[0-9])))))?$").matcher(didLoanDate).matches()) {
            remark = String.valueOf(remark) + " 贷款发放日期不符合规则";
        }
        if ("".equals(didLoanRepayDate) || didLoanRepayDate == null) {
            remark = String.valueOf(remark) + " 贷款偿还日期为空";
        } else if (!Pattern.compile("^((\\d{2}(([02468][048])|([13579][26]))[\\-]{1}((((0?[13578])|(1[02]))[\\-]{1}((0?[1-9])|([1-2][0-9])|(3[01])))|(((0?[469])|(11))[\\-]{1}((0?[1-9])|([1-2][0-9])|(30)))|(0?2[\\-]{1}((0?[1-9])|([1-2][0-9])))))|(\\d{2}(([02468][1235679])|([13579][01345789]))[\\-]{1}((((0?[13578])|(1[02]))[\\-]{1}((0?[1-9])|([1-2][0-9])|(3[01])))|(((0?[469])|(11))[\\-]{1}((0?[1-9])|([1-2][0-9])|(30)))|(0?2[\\-]{1}((0?[1-9])|(1[0-9])|(2[0-8]))))))?\\s{1}((((0?[0-9])|([1][0-9])|([2][0-4]))\\:([0-5]?[0-9])((\\s)|(\\:([0-5]?[0-9])))))?$").matcher(didLoanRepayDate).matches()) {
            remark = String.valueOf(remark) + " 贷款偿还日期不符合规则";
        }
        if ("".equals(didLoanDeclaration) || didLoanDeclaration == null) {
            remark = String.valueOf(remark) + " 贷款申报日期为空";
        } else if (!Pattern.compile("^((\\d{2}(([02468][048])|([13579][26]))[\\-]{1}((((0?[13578])|(1[02]))[\\-]{1}((0?[1-9])|([1-2][0-9])|(3[01])))|(((0?[469])|(11))[\\-]{1}((0?[1-9])|([1-2][0-9])|(30)))|(0?2[\\-]{1}((0?[1-9])|([1-2][0-9])))))|(\\d{2}(([02468][1235679])|([13579][01345789]))[\\-]{1}((((0?[13578])|(1[02]))[\\-]{1}((0?[1-9])|([1-2][0-9])|(3[01])))|(((0?[469])|(11))[\\-]{1}((0?[1-9])|([1-2][0-9])|(30)))|(0?2[\\-]{1}((0?[1-9])|(1[0-9])|(2[0-8]))))))?\\s{1}((((0?[0-9])|([1][0-9])|([2][0-4]))\\:([0-5]?[0-9])((\\s)|(\\:([0-5]?[0-9])))))?$").matcher(didLoanDeclaration).matches()) {
            remark = String.valueOf(remark) + " 贷款申报日期不符合规则";
        }
        result.put("didCorName", didCorName);
        result.put("didLoanProsess", didLoanProsess);
        result.put("didType", didType);
        result.put("didFinanceName", didFinanceName);
        result.put("didApplyAmt", didApplyAmt);
        result.put("didLocalAgreeAmt", didLocalAgreeAmt);
        result.put("didProAgreeAmt", didProAgreeAmt);
        result.put("didLocalRisk", didLocalRisk);
        result.put("didLocFilingDate", didLocFilingDate);
        result.put("didActualLoanAmt", didActualLoanAmt);
        result.put("didLoanDate", didLoanDate);
        result.put("didLoanRepayDate", didLoanRepayDate);
        result.put("didLoanDeclaration", didLoanDeclaration);
        result.put("didRemark", remark);
        return result;
    }

    private Map getRecordMap(HSSFRow recordRow, String formatter) throws TranFailException {
        Map result = new HashMap();
        StringTokenizer formatters = new StringTokenizer(formatter, "||");
        int i = 0;
        while (formatters.hasMoreTokens()) {
            String name = (String) formatters.nextElement();
            result.put(name, getCellContent(recordRow, i, true));
            i++;
        }
        return result;
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    private String getCellContent(HSSFRow row, int index, boolean toInt) throws TranFailException {
        String result = null;
        try {
            HSSFCell cell = row.getCell(index);
            if (cell != null) {
                switch (cell.getCellType()) {
                    case 0:
                        String format = "######.##";
                        if (toInt) {
                            format = "#######";
                        }
                        if (HSSFDateUtil.isCellDateFormatted(cell)) {
                            result = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(HSSFDateUtil.getJavaDate(cell.getNumericCellValue()));
                            break;
                        } else {
                            result = new DecimalFormat(format).format(cell.getNumericCellValue());
                            break;
                        }
                    case 1:
                        result = cell.getRichStringCellValue().getString();
                        break;
                }
            }
            return result == null ? "" : result.trim();
        } catch (Exception ex) {
            Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }
}
